# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import GridExportMode, MethodFromLibraryIonMode, Properties
from .Compliance import ICompliance
from .Toolbar import IToolBeforeDropdownHandler, IToolHandler, IToolState
from .UIScriptIF import IGrid, IUIState, IWorktablePane

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ToolDefinitions

class AddSamplesHelper(System.IDisposable):  # Class
    @staticmethod
    def Do(uiState: IUIState) -> None: ...
    def Dispose(self) -> None: ...

class AnalyzeToolHandler(IToolHandler):  # Class
    def __init__(self) -> None: ...

class AutoSIMDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self, uiState: IUIState) -> None: ...

class CalCurveToolHandler(IToolHandler, IToolBeforeDropdownHandler):  # Class
    def __init__(self) -> None: ...

class CalibrationDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(
        self,
        uiState: IUIState,
        type: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ToolDefinitions.CalibrationDialog.OperationType,
    ) -> None: ...

    # Nested Types

    class OperationType(
        System.IConvertible, System.IComparable, System.IFormattable
    ):  # Struct
        Add: (
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.ToolDefinitions.CalibrationDialog.OperationType
        ) = ...  # static # readonly
        Average: (
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.ToolDefinitions.CalibrationDialog.OperationType
        ) = ...  # static # readonly
        Clear: (
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.ToolDefinitions.CalibrationDialog.OperationType
        ) = ...  # static # readonly
        Remove: (
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.ToolDefinitions.CalibrationDialog.OperationType
        ) = ...  # static # readonly
        Replace: (
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.ToolDefinitions.CalibrationDialog.OperationType
        ) = ...  # static # readonly

class ChromSpecToolHandler(IToolHandler):  # Class
    def __init__(self) -> None: ...

class ColorSchemeDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

class EditToolHandler(IToolHandler):  # Class
    def __init__(self) -> None: ...

class FileToolHandler(IToolHandler, IToolBeforeDropdownHandler):  # Class
    def __init__(self) -> None: ...

    ExcelExt: str = ...  # static # readonly
    FilterIndex_CSV: int = ...  # static # readonly
    FilterIndex_Excel: int = ...  # static # readonly
    FilterIndex_Text: int = ...  # static # readonly
    FilterIndex_Xml: int = ...  # static # readonly

    @staticmethod
    def ExportTable(
        state: IUIState,
        grid: IGrid,
        filename: str,
        filterindex: int,
        openfile: bool,
        mode: GridExportMode,
    ) -> None: ...

class FindDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...
    def Initialize(self, uiState: IUIState, grid: IGrid) -> None: ...

class FitToLevelsDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

    IsOriginSelected: bool  # readonly
    ShowOrigin: bool

    def SetLevelNames(self, levelNames: Iterable[str]) -> None: ...
    def GetSelectedLevelNames(self) -> List[str]: ...

class HelpToolHandler(IToolHandler):  # Class
    def __init__(self) -> None: ...

class LibraryToolHandler(IToolHandler):  # Class
    def __init__(self) -> None: ...
    def Execute(self, toolState: IToolState, uiStateObj: Any) -> None: ...
    def SetState(self, toolState: IToolState, uiStateObj: Any) -> None: ...

class MSScanTypesDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self, uiState: IUIState) -> None: ...

class MethodFrom2DDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self, uiState: IUIState) -> None: ...

    Append: bool
    EndTime: Optional[float]  # readonly
    MaxNumPeaks: Optional[int]  # readonly
    PeakAreaAbs: Optional[float]  # readonly
    PeakAreaRel: Optional[float]  # readonly
    PeakFilterType: Agilent.MassSpectrometry.DataAnalysis.PeakFilterType  # readonly
    PeakHeightAbs: Optional[float]  # readonly
    PeakHeightRel: Optional[float]  # readonly
    SNR: Optional[float]  # readonly
    SamplePath: str
    StartTime: Optional[float]  # readonly

class MethodFromLibraryDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self, compliance: ICompliance) -> None: ...

    CompoundListFile: str
    CreateTargetsPerSpectrum: bool
    Library: str
    NumQualifiers: int
    PickIonsFromMultipleSpectra: bool
    RTCal: str
    Sample: str  # readonly
    Species: List[str]  # readonly
    SumQualifiersFromAdditionalSpectra: bool
    TargetIonMode: MethodFromLibraryIonMode
    UpdateRTFromSample: bool
    UseCompoundList: bool
    UseRTCal: bool

class MethodFromScanDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self, uiState: IUIState) -> None: ...

    CreateSimMethd: bool
    NumQualifiers: int
    SamplePath: str

class MethodFromScanWithLibSrchDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self, uiState: IUIState, librarySearch: bool) -> None: ...

    CreateSimMethod: bool
    LibraryMethodPath: str
    NumQualifiers: int
    SamplePath: str

class MethodToolHandler(IToolHandler, IToolBeforeDropdownHandler):  # Class
    def __init__(self) -> None: ...

class MetricsPlotToolHandler(IToolHandler):  # Class
    def __init__(self) -> None: ...

class QualLauncher:  # Class
    def __init__(self) -> None: ...

    ScriptLanguage: str
    UIState: IUIState

    def Launch(self) -> None: ...

class ReportToolHandler(IToolHandler, IToolBeforeDropdownHandler):  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def GenerateDefaultOutputDirectory(
        compliance: ICompliance, batchFolder: str, batchFileName: str
    ) -> str: ...

class SampleDataToolHandler(IToolHandler, IToolBeforeDropdownHandler):  # Class
    def __init__(self) -> None: ...

class SampleGroupFilterDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

class SampleTypeFilterDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

    AutoClose: bool

    def InitializeItems(self, worktable: IWorktablePane) -> None: ...

class ScriptToolHandler(IToolHandler):  # Class
    def __init__(self) -> None: ...
    def Execute(self, toolState: IToolState, uiStateObj: Any) -> None: ...
    def SetState(self, toolState: IToolState, uiState: Any) -> None: ...

class SetupReferencePatternLibraryDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self, uiState: IUIState) -> None: ...
    def InitControls(self) -> None: ...

class SimpleReportDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

    PDFtoScreen: bool
    PrintToDefaultPrinter: bool
    ReportFolder: str
    ShowAdvanced: bool  # readonly
    ShowQueueViewer: bool  # readonly
    SingleSampleMode: bool
    Template: str

class ToolUtils:  # Class
    @staticmethod
    def CheckException(uiState: IUIState, e: System.Exception) -> bool: ...
    @staticmethod
    def ReopenSamples(iuiState: IUIState) -> None: ...

class ToolsToolHandler(IToolHandler, IToolBeforeDropdownHandler):  # Class
    def __init__(self) -> None: ...

class UpdateToolHandler(IToolHandler):  # Class
    def __init__(self) -> None: ...

class ViewToolHandler(IToolHandler, IToolBeforeDropdownHandler):  # Class
    def __init__(self) -> None: ...

class WorktableToolHandler(IToolHandler, IToolBeforeDropdownHandler):  # Class
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .QueuedTask import QueuedTasks

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.FileMessaging

class DirectoryWatcher(System.IDisposable):  # Class
    def __init__(
        self,
        queue: Agilent.MassSpectrometry.DataAnalysis.Quantitative.FileMessaging.WatchFileProcessQueue,
        wpe: Agilent.MassSpectrometry.DataAnalysis.Quantitative.FileMessaging.WatchPathEntry,
    ) -> None: ...
    def Dispose(self) -> None: ...

class FileMessagingLog(System.IDisposable):  # Class
    def __init__(self) -> None: ...
    def CloseEventLog(self) -> None: ...
    @staticmethod
    def Log(
        filelog: Agilent.MassSpectrometry.DataAnalysis.Quantitative.FileMessaging.FileMessagingLog,
        type: System.Diagnostics.EventLogEntryType,
        trace: bool,
        cat: str,
        format: str,
        args: List[Any],
    ) -> None: ...
    @staticmethod
    def LogWarning(
        log: Agilent.MassSpectrometry.DataAnalysis.Quantitative.FileMessaging.FileMessagingLog,
        trace: bool,
        cat: str,
        format: str,
        args: List[Any],
    ) -> None: ...
    @staticmethod
    def LogInfo(
        log: Agilent.MassSpectrometry.DataAnalysis.Quantitative.FileMessaging.FileMessagingLog,
        trace: bool,
        cat: str,
        format: str,
        args: List[Any],
    ) -> None: ...
    def StartEventLog(self, source: str) -> None: ...
    def Dispose(self) -> None: ...
    @staticmethod
    def LogError(
        log: Agilent.MassSpectrometry.DataAnalysis.Quantitative.FileMessaging.FileMessagingLog,
        trace: bool,
        cat: str,
        format: str,
        args: List[Any],
    ) -> None: ...

class IQueuedTaskEventSink(object):  # Interface
    def OnTaskFinish(
        self,
        info: Agilent.MassSpectrometry.DataAnalysis.Quantitative.FileMessaging.QueuedTaskInformation,
        e: System.Exception,
    ) -> None: ...
    def OnTaskStart(
        self,
        info: Agilent.MassSpectrometry.DataAnalysis.Quantitative.FileMessaging.QueuedTaskInformation,
    ) -> None: ...

class PriorityEnum(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    AboveNormal: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.FileMessaging.PriorityEnum
    ) = ...  # static # readonly
    High: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.FileMessaging.PriorityEnum
    ) = ...  # static # readonly
    Highest: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.FileMessaging.PriorityEnum
    ) = ...  # static # readonly
    Low: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.FileMessaging.PriorityEnum
    ) = ...  # static # readonly
    Lowest: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.FileMessaging.PriorityEnum
    ) = ...  # static # readonly
    Normal: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.FileMessaging.PriorityEnum
    ) = ...  # static # readonly
    VeryHigh: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.FileMessaging.PriorityEnum
    ) = ...  # static # readonly
    VeryLow: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.FileMessaging.PriorityEnum
    ) = ...  # static # readonly

class QueuedTaskInformation:  # Class
    Completion: System.DateTime  # readonly
    Creation: System.DateTime  # readonly
    Host: str  # readonly
    Name: str  # readonly
    Owner: str  # readonly
    Path: str  # readonly
    Status: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.FileMessaging.QueuedTaskStatus
    )  # readonly

    def Equals(
        self,
        info: Agilent.MassSpectrometry.DataAnalysis.Quantitative.FileMessaging.QueuedTaskInformation,
    ) -> bool: ...

class QueuedTaskStatus(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Canceled: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.FileMessaging.QueuedTaskStatus
    ) = ...  # static # readonly
    Done: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.FileMessaging.QueuedTaskStatus
    ) = ...  # static # readonly
    Error: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.FileMessaging.QueuedTaskStatus
    ) = ...  # static # readonly
    Processing: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.FileMessaging.QueuedTaskStatus
    ) = ...  # static # readonly
    Unknown: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.FileMessaging.QueuedTaskStatus
    ) = ...  # static # readonly
    Waiting: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.FileMessaging.QueuedTaskStatus
    ) = ...  # static # readonly

class QueuedTaskWatchEntry(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.FileMessaging.WatchPathEntry,
    System.IDisposable,
    System.ICloneable,
):  # Class
    def __init__(self) -> None: ...

    Controller: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.FileMessaging.QueuedTaskWatchPathController
    )
    Tasks: QueuedTasks  # readonly

    def BeginProcess(
        self, callback: System.AsyncCallback, asyncState: Any
    ) -> System.IAsyncResult: ...
    def Abort(self) -> None: ...
    def Clone(self) -> Any: ...

class QueuedTaskWatchPathController(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.FileMessaging.WatchPathController,
    System.IDisposable,
):  # Class
    def __init__(self) -> None: ...

    QueueDirectory: str  # static # readonly
    WatchDirectory: str  # static # readonly

    def Start(self) -> None: ...
    def Stop(self) -> None: ...
    def EventSink(
        self,
        sink: Agilent.MassSpectrometry.DataAnalysis.Quantitative.FileMessaging.IQueuedTaskEventSink,
        register: bool,
    ) -> None: ...
    @staticmethod
    def GetQueueTasks(
        watchpath: str, queuedirectory: str
    ) -> Iterable[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.FileMessaging.QueuedTaskInformation
    ]: ...
    def GetProcessingTasks(
        self,
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.FileMessaging.QueuedTaskInformation
    ]: ...

class ServiceObject(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.FileMessaging.IQueuedTaskEventSink,
    System.ServiceProcess.ServiceBase,
    System.ComponentModel.IComponent,
):  # Class
    def __init__(self) -> None: ...

    IsLocked: bool  # static # readonly
    IsRunning: bool  # readonly

    def DeleteTasks(
        self,
        tasks: Iterable[
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.FileMessaging.QueuedTaskInformation
        ],
    ) -> None: ...
    def Lock(self) -> None: ...
    def UserStop(self) -> None: ...
    def EventSink(
        self,
        sink: Agilent.MassSpectrometry.DataAnalysis.Quantitative.FileMessaging.IQueuedTaskEventSink,
        register: bool,
    ) -> None: ...
    def RetryTasks(
        self,
        tasks: Iterable[
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.FileMessaging.QueuedTaskInformation
        ],
    ) -> None: ...
    @staticmethod
    def ConnectToServer() -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.FileMessaging.ServiceObject
    ): ...
    @staticmethod
    def CreateServer() -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.FileMessaging.ServiceObject
    ): ...
    def UserStart(self) -> None: ...
    @staticmethod
    def SetupLogTraceListener(configSetting: str) -> None: ...
    def GetTaskInformation(
        self,
    ) -> Iterable[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.FileMessaging.QueuedTaskInformation
    ]: ...

class WatchFileProcessQueue(System.IDisposable):  # Class
    def __init__(self) -> None: ...
    def AddPath(
        self,
        entry: Agilent.MassSpectrometry.DataAnalysis.Quantitative.FileMessaging.WatchPathEntry,
    ) -> None: ...
    def Abort(self) -> None: ...
    def Dispose(self) -> None: ...
    def GetProcessingEntries(
        self,
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.FileMessaging.WatchPathEntry
    ]: ...

class WatchPathController(System.IDisposable):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, configfilename: str) -> None: ...

    Log: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.FileMessaging.FileMessagingLog
    )

    def Start(self) -> None: ...
    def Dispose(self) -> None: ...
    def Stop(self) -> None: ...

class WatchPathEntry(System.IDisposable, System.ICloneable):  # Class
    def __init__(self) -> None: ...

    filter: str
    includesubdirectories: bool
    queuefilename: str
    type: str
    watchfilename: str
    watchname: str

    Log: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.FileMessaging.FileMessagingLog
    )
    queuedirectory: str
    watchpath: str

    def EndProcess(self, result: System.IAsyncResult) -> None: ...
    def Abort(self) -> None: ...
    def Clone(self) -> Any: ...
    def BeginProcess(
        self, callback: System.AsyncCallback, asyncState: Any
    ) -> System.IAsyncResult: ...
    def Dispose(self) -> None: ...

class WatchPaths(System.MarshalByRefObject):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, WatchConfigName: str) -> None: ...

    Log: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.FileMessaging.FileMessagingLog
    )
    WatchConfigName: str  # readonly
    WatchPathsTable: System.Data.DataTable  # readonly

    def Load(self) -> None: ...

    Changed: System.EventHandler  # Event
    Deleted: System.EventHandler  # Event



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import (
    BatchAttributes,
    ChromatogramPeakLabelType,
    CompoundIdentificationParams,
    GridExportMode,
    InstrumentType,
    INumericCustomFormat,
    INumericFormat,
    PlotTitleElement,
    PresentationState,
    QuantitationDataSet,
)
from .Compliance import IAuditTrail, ICompliance
from .Grid import GridControlBase
from .UIScriptIF import IAddInManager, IExportPlotParameters, IUIState
from .UnknownsMethod import MethodControl

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Dialogs

class AddinsDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self, uiState: IUIState, manager: IAddInManager) -> None: ...

class AuditTrailDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self, auditTrail: IAuditTrail) -> None: ...

class AuditTrailGrid(
    Infragistics.Win.IUltraControl,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.Layout.IArrangedElement,
    Infragistics.Win.IUIElementProvider,
    Infragistics.Win.IUltraControlElement,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.ComponentModel.ISupportInitialize,
    Infragistics.Shared.Serialization.ICodeDomSerializable,
    Infragistics.Win.UIAutomation.IProvideUIAutomation,
    System.Windows.Forms.IWin32Window,
    Infragistics.Win.ISupportPresets,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    Infragistics.Win.AppStyling.ISupportAppStyling,
    Infragistics.Win.IControlElementEventProcessor,
    Infragistics.Win.IUIElementTextProvider,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    Infragistics.Win.CalcEngine.IUltraCalcParticipant,
    System.ComponentModel.ISynchronizeInvoke,
    Infragistics.Win.IValidatorClient,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    Agilent.MassHunter.Quantitative.UIModel.IGridControl,
    Infragistics.Win.Touch.ISupportTouchMetrics,
    System.ComponentModel.IComponent,
    Infragistics.Win.ISelectionManager,
    Infragistics.Win.UltraWinGrid.Design.IGridDesignInfo,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    Infragistics.Win.Touch.IGestureConsumer,
    Infragistics.Shared.IUltraLicensedComponent,
    GridControlBase,
    System.Windows.Forms.IBindableComponent,
    System.IDisposable,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    Infragistics.Win.AutoEditMode.IAutoEditMode,
):  # Class
    def __init__(self) -> None: ...

class AverageQualifierRatiosDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Dialogs.SelectDataRowsDialog,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

    CalsChecked: bool
    QCsChecked: bool

class AverageRetentionTimeDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Dialogs.SelectDataRowsDialog,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

    Cals: bool
    Qcs: bool
    UseWeightings: bool
    Weight: float

class BatchAttributesDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...
    def Initialize(
        self,
        instrument: InstrumentType,
        attrs: BatchAttributes,
        numericFormat: INumericFormat,
    ) -> None: ...

class BatchFileDialog(System.IDisposable):  # Class
    def __init__(
        self,
        mode: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Dialogs.BatchFileDialogMode,
    ) -> None: ...

    AllowAuditTrail: bool
    AllowReadonly: bool
    AuditTrail: bool
    AuditTrailCheckboxEnabled: bool
    BatchFile: str  # readonly
    BatchFolder: str  # readonly
    HelpFile: str
    HelpId: int
    InitialDir: str
    Readonly: bool
    Title: str

    def Dispose(self) -> None: ...
    def ShowDialog(self, parent: System.Windows.Forms.IWin32Window) -> bool: ...

class BatchFileDialogMode(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    New: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Dialogs.BatchFileDialogMode
    ) = ...  # static # readonly
    Open: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Dialogs.BatchFileDialogMode
    ) = ...  # static # readonly
    SaveAs: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Dialogs.BatchFileDialogMode
    ) = ...  # static # readonly

class ChooseSpeciesControl(
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UserControl,
):  # Class
    def __init__(self) -> None: ...

    TextBoxText: str

    def GetSelectedSpecies(self) -> Iterable[str]: ...
    def GetAvailableSpecies(self) -> Iterable[str]: ...
    def SetAvailableSpecies(self, species: Iterable[str]) -> None: ...
    def SetSelectedSpecies(self, species: Iterable[str]) -> None: ...

    ValidateNewSpecies: System.ComponentModel.CancelEventHandler  # Event

class ChooseSpeciesDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...
    def GetSelectedSpecies(self) -> Iterable[str]: ...
    def SetSelectedSpecies(self, species: List[str]) -> None: ...

class DirectoriesDialog(System.IDisposable):  # Class
    def __init__(self) -> None: ...

    AllowMultiSelect: bool
    Directories: str  # readonly
    DirectoryMustExist: bool
    Extension: str
    FileFilter: str
    HelpFile: str
    HelpTopicId: int
    InitialDir: str
    Readonly: bool
    ReadonlyCheckbox: bool
    Title: str

    def Dispose(self) -> None: ...
    def ShowDialog(self, parent: System.Windows.Forms.IWin32Window) -> bool: ...

class ExportFileDialog(System.IDisposable):  # Class
    def __init__(self) -> None: ...

    ExportMode: GridExportMode
    FileName: str  # readonly
    Filter: str
    FilterIndex: int
    HelpFile: str
    HelpTopicId: int
    InitialDir: str
    OpenFile: bool
    Title: str

    def Dispose(self) -> None: ...
    def ShowDialog(self, parent: System.Windows.Forms.IWin32Window) -> bool: ...

class ExportPlotDialog:  # Class
    @staticmethod
    def ShowDialog(
        parent: Agilent.MassSpectrometry.GUI.Plot.PlotControl,
        parameters: IExportPlotParameters,
    ) -> bool: ...

class LibraryDialog(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Dialogs.ShellFileDialogBase,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(
        self,
        dialogType: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Dialogs.ShellFileDialogType,
    ) -> None: ...

    AllowNistLibraries: bool
    ExtraFileFilter: str

    def AllowReferenceLibrary(self) -> None: ...
    def ShowDialog(
        self, parent: System.Windows.Forms.IWin32Window
    ) -> System.Windows.Forms.DialogResult: ...

class LibraryMethodDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self, compliance: ICompliance) -> None: ...

    MethodControl: MethodControl  # readonly
    MethodPath: str  # readonly

    def InitNew(self, referenceSampleFilePath: str) -> None: ...
    def Initialize(
        self, methodPath: str, revisionNumber: str, referenceSampleFilePath: str
    ) -> None: ...

class LogonUserDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

    Compliance: ICompliance
    Domain: str
    Password: System.Security.SecureString  # readonly
    User: str
    ValidationMode: bool

    Cancel: System.ComponentModel.CancelEventHandler  # Event
    Logon: System.ComponentModel.CancelEventHandler  # Event

class MatrixOverrideControl(
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UserControl,
):  # Class
    def __init__(self) -> None: ...
    def SaveTo(self, writer: System.IO.TextWriter) -> bool: ...
    def Initialize(self, pstate: PresentationState, value_: str) -> None: ...
    def ValidateItems(self) -> bool: ...

class MethodFileDialog(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Dialogs.ShellFileDialogBase,
):  # Class
    @overload
    def __init__(self, saveAs: bool, individualFileExtension: str) -> None: ...
    @overload
    def __init__(self, saveAs: bool, individualFileExtensions: List[str]) -> None: ...

class NumberFormatColumn:  # Class
    def __init__(
        self, name: str, displayText: str, category: str, format: INumericCustomFormat
    ) -> None: ...

    Category: str  # readonly
    CategoryDisplayText: str  # readonly
    DisplayText: str  # readonly
    Format: INumericCustomFormat
    FormatPattern: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Dialogs.NumberFormatPattern
    )
    Name: str  # readonly
    Precision: Optional[int]

class NumberFormatControl(
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UserControl,
):  # Class
    def __init__(self) -> None: ...

    Formats: Iterable[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Dialogs.NumberFormatColumn
    ]
    ReadOnly: bool

    def InvalidateContent(self) -> None: ...
    def SetDateTimeMode(self) -> None: ...
    def SetFormat(
        self,
        column: str,
        pattern: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Dialogs.NumberFormatPattern,
        precision: Optional[int],
    ) -> None: ...
    def PerformAutoResizeColumns(self) -> None: ...
    def SetNumberMode(self) -> None: ...

    ValueChanged: System.EventHandler  # Event

class NumberFormatDateTimeColumnDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self, type: System.Type) -> None: ...

    Format: str

    Apply: System.ComponentModel.CancelEventHandler  # Event

class NumberFormatDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self, uiState: IUIState) -> None: ...

    Formats: Iterable[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Dialogs.NumberFormatColumn
    ]

    def Initialize(self, instrumentType: InstrumentType) -> None: ...

class NumberFormatPattern(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    DateTime: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Dialogs.NumberFormatPattern
    ) = ...  # static # readonly
    Exponential: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Dialogs.NumberFormatPattern
    ) = ...  # static # readonly
    FixedPoint: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Dialogs.NumberFormatPattern
    ) = ...  # static # readonly
    General: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Dialogs.NumberFormatPattern
    ) = ...  # static # readonly
    SignificantFigures: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Dialogs.NumberFormatPattern
    ) = ...  # static # readonly

class NumberFormatSingleColumnControl(
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UserControl,
):  # Class
    def __init__(self) -> None: ...

    DefaultFormatPattern: Optional[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Dialogs.NumberFormatPattern
    ]
    DefaultPrecision: Optional[int]
    FormatPattern: Optional[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Dialogs.NumberFormatPattern
    ]
    Precision: Optional[int]

    def SetDefault(self) -> None: ...

class NumberFormatSingleColumnDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

    DefaultFormatPattern: Optional[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Dialogs.NumberFormatPattern
    ]
    DefaultPrecision: Optional[int]
    FormatPattern: Optional[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Dialogs.NumberFormatPattern
    ]
    Precision: Optional[int]

    Apply: System.ComponentModel.CancelEventHandler  # Event

class PeakColorsDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

    Accepted: System.Drawing.Color
    Alternate: System.Drawing.Color
    Inspected: System.Drawing.Color
    ManualIntegrated: System.Drawing.Color
    Rejected: System.Drawing.Color

class PeakLabelsControl(
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UserControl,
):  # Class
    def __init__(self) -> None: ...

    IsDirty: bool  # readonly
    ShowLabelNames: bool  # readonly
    ShowUnits: bool  # readonly

    def Initialize(
        self,
        instrumentType: InstrumentType,
        types: List[ChromatogramPeakLabelType],
        showLabelNames: bool,
        showUnits: bool,
    ) -> None: ...
    def ClearDirty(self) -> None: ...
    def GetPeakLabelTypes(self) -> List[ChromatogramPeakLabelType]: ...

    PeakLabelsChanged: System.EventHandler  # Event

class PeakLabelsDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

    PeakLabelsControl: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Dialogs.PeakLabelsControl
    )  # readonly

class PlotTitleElementControl(
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UserControl,
):  # Class
    def __init__(self) -> None: ...

    ShowDefaultTitles: bool

    def SetValues(
        self,
        showDefaultTitle: bool,
        availableElements: List[PlotTitleElement],
        elements: List[PlotTitleElement],
    ) -> None: ...
    def GetElements(self) -> List[PlotTitleElement]: ...

class PlotTitleElementDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

    ShowDefaultTitles: bool

    @overload
    def SetValues(
        self, showDefaultTitle: bool, elements: List[PlotTitleElement]
    ) -> None: ...
    @overload
    def SetValues(
        self,
        showDefaultTitle: bool,
        availableElements: List[PlotTitleElement],
        elements: List[PlotTitleElement],
    ) -> None: ...
    def GetElements(self) -> List[PlotTitleElement]: ...

class RTCalibrationDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self, compliance: ICompliance) -> None: ...

    BatchFile: str
    BatchFolder: str
    InitialBatchFolder: str
    InitialLibraryFolder: str
    Library: str
    Output: str

class ReportMethodFileDialog(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Dialogs.ShellFileDialogBase,
):  # Class
    def __init__(
        self,
        type: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Dialogs.ShellFileDialogType,
        isUnknowns: bool,
    ) -> None: ...

class SampleDirectoriesDialog(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Dialogs.DirectoriesDialog,
    System.IDisposable,
):  # Class
    def __init__(self) -> None: ...

class SelectDataRowsDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

    DataView: System.Data.DataView  # readonly
    LabelText: str
    MultiSelect: bool

    def GetSelectedRows(self) -> List[System.Data.DataRow]: ...
    def ClearColumns(self) -> None: ...
    def SetDataView(self, view: System.Data.DataView) -> None: ...
    @overload
    def AddColumn(self, property: str, caption: str) -> None: ...
    @overload
    def AddColumn(
        self, property: str, caption: str, format: INumericCustomFormat
    ) -> None: ...
    def SelectRows(self, condition: str, clearSelection: bool) -> None: ...

class SelectSampleFoldersDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    @overload
    def __init__(self, compliance: ICompliance) -> None: ...
    @overload
    def __init__(
        self, compliance: ICompliance, instrumentType: InstrumentType
    ) -> None: ...

    BatchDataTable: QuantitationDataSet.BatchDataTable  # readonly
    BatchFolder: str
    CopySampleEnabled: bool
    MultipleSelection: bool

    def SetSelectedSampleFolders(self, folders: List[str]) -> None: ...
    def GetSelectedSampleFolders(self) -> List[str]: ...
    def InitSamplesInBatch(self, samples: List[str]) -> None: ...
    def GetSamplesInBatch(self) -> List[str]: ...
    def SelectAllSamples(self) -> None: ...

    Initialized: System.EventHandler  # Event

class SelectedMzMarkerDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

    Color: Optional[System.Drawing.Color]
    Fill: bool
    Size: Optional[int]

class SetupReferenceLibraryDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self, uiState: IUIState) -> None: ...

class ShellFileDialogBase(System.IDisposable):  # Class
    def __init__(
        self,
        type: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Dialogs.ShellFileDialogType,
    ) -> None: ...

    DefaultExtension: str
    DialogType: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Dialogs.ShellFileDialogType
    )  # readonly
    EnsurePathExists: bool
    InitialDirectory: str
    Multiselect: bool
    OverwritePrompt: bool
    PathName: str  # readonly
    Readonly: bool
    ReadonlyCheckbox: bool
    Title: str

    def ShowDialog(
        self, parent: System.Windows.Forms.IWin32Window
    ) -> System.Windows.Forms.DialogResult: ...
    def Dispose(self) -> None: ...
    def AddFilter(
        self,
        name: str,
        filters: Iterable[
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.Dialogs.ShellFileDialogFilter
        ],
    ) -> None: ...
    def ClearFilters(self) -> None: ...

    SaveAsFile: System.ComponentModel.CancelEventHandler  # Event
    SaveAsFolder: System.ComponentModel.CancelEventHandler  # Event

class ShellFileDialogFilter:  # Class
    def __init__(self, extensions: List[str], isFolder: bool) -> None: ...

    Extensions: List[str]
    IsFolder: bool

class ShellFileDialogType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    New: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Dialogs.ShellFileDialogType
    ) = ...  # static # readonly
    Open: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Dialogs.ShellFileDialogType
    ) = ...  # static # readonly
    SaveAs: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Dialogs.ShellFileDialogType
    ) = ...  # static # readonly

class ShiftRetentionTimeDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Dialogs.SelectDataRowsDialog,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

    AbsoluteShift: float
    RelativeShift: float

class SystemInfoDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def ShowSystemInfo(parent: System.Windows.Forms.IWin32Window) -> None: ...

class SystemInfoItem:  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, fileVersionInfo: System.Diagnostics.FileVersionInfo) -> None: ...
    @overload
    def __init__(
        self,
        fileVersionInfo: System.Diagnostics.FileVersionInfo,
        assembly: System.Reflection.Assembly,
    ) -> None: ...

    AssemblyConfiguration: str  # readonly
    AssemblyCulture: str  # readonly
    AssemblyTitle: str  # readonly
    ComVisible: Optional[bool]  # readonly
    Comments: str  # readonly
    CompanyName: str  # readonly
    FileDescription: str  # readonly
    FileVersion: str  # readonly
    Guid: str  # readonly
    InternalName: str  # readonly
    IsDebug: Optional[bool]  # readonly
    IsPatched: Optional[bool]  # readonly
    IsPrivateBuild: Optional[bool]  # readonly
    IsSpecialBuild: Optional[bool]  # readonly
    Language: str  # readonly
    LegalCopyright: str  # readonly
    LegalTrademarks: str  # readonly
    Location: str  # readonly
    Name: str  # readonly
    PrivateBuild: str  # readonly
    ProductName: str  # readonly
    ProductVersion: str  # readonly
    SpecialBuild: str  # readonly

class SystemInfoItemCollection(
    Sequence[Agilent.MassSpectrometry.DataAnalysis.Quantitative.Dialogs.SystemInfoItem],
    System.ComponentModel.IRaiseItemChangedEvents,
    System.ComponentModel.BindingList[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Dialogs.SystemInfoItem
    ],
    List[Agilent.MassSpectrometry.DataAnalysis.Quantitative.Dialogs.SystemInfoItem],
    System.ComponentModel.IBindingList,
    System.ComponentModel.ICancelAddNew,
    Iterable[Agilent.MassSpectrometry.DataAnalysis.Quantitative.Dialogs.SystemInfoItem],
    System.ComponentModel.IComponent,
    List[Any],
    Iterable[Any],
    Sequence[Any],
    System.IDisposable,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, container: System.ComponentModel.IContainer) -> None: ...

    SynchronizeInvoke: System.ComponentModel.ISynchronizeInvoke

    def Dispose(self) -> None: ...

class UnknownsAnalysisParametersDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

    ComponentPerceptionParams: (
        Agilent.MassSpectrometry.DataAnalysis.ComponentPerceptionParams
    )
    CompoundIdentificationParams: CompoundIdentificationParams
    HideDisabledPage: bool
    LibrarySearchParams: Agilent.MassSpectrometry.DataAnalysis.LibrarySearchParams
    SeparationTechniqueForDefault: Optional[
        Agilent.MassSpectrometry.DataAnalysis.SeparationTechnique
    ]

    def SelectComponentPerceptionTab(self) -> None: ...
    def SelectCompoundIdentificationTab(self) -> None: ...
    def SelectLibrarySearchTab(self) -> None: ...

class ValidateUserDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

    Compliance: ICompliance
    Message: str

class ValidateUserReasonDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

    ActionString: str
    Compliance: ICompliance
    MaxTrial: int
    ReasonEnabled: bool
    ValidateUserEnabled: bool



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CustomDialogs

class BATCHFILEINFO:  # Struct
    Analyst: str
    AuditTrail: bool
    BatchFile: str
    DataVersion: int
    DateAnalyzed: float
    DateLastSaved: float
    Size: int
    lStructSize: int

class EGDFLAGS(System.IConvertible, System.IComparable, System.IFormattable):  # Struct
    EGD_DISABLE_PANES: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CustomDialogs.EGDFLAGS
    ) = ...  # static # readonly
    EGD_DISABLE_SCALE: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CustomDialogs.EGDFLAGS
    ) = ...  # static # readonly
    EGD_FIT_TO: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CustomDialogs.EGDFLAGS
    ) = ...  # static # readonly
    EGD_SELECTED_PANE: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CustomDialogs.EGDFLAGS
    ) = ...  # static # readonly
    EGD_UNIT_CM: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CustomDialogs.EGDFLAGS
    ) = ...  # static # readonly
    EGD_UNIT_INCHES: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CustomDialogs.EGDFLAGS
    ) = ...  # static # readonly

class EXPORTFILEDIALOG:  # Struct
    fOpenFile: bool
    hwndOwner: System.IntPtr
    lStructSize: int
    lpstrFile: str
    lpstrFilter: str
    lpstrHelpFile: str
    lpstrInitialDir: str
    lpstrTitle: str
    nFilterIndex: int
    nHelpTopicId: int

class EXPORTGRAPHICSFILEDIALOG:  # Struct
    Flags: int
    dpix: float
    dpiy: float
    height: float
    hwndOwner: System.IntPtr
    lStructSize: int
    lpstrFile: str
    lpstrFilter: str
    lpstrHelpFile: str
    lpstrInitialDir: str
    lpstrTitle: str
    nFilterIndex: int
    nHelpTopicId: int
    scale: float
    width: float

class GRAPHICSPAGESETUPDIALOG:  # Struct
    Flags: int
    hDevMode: System.IntPtr
    hDevNames: System.IntPtr
    hPreview: System.IntPtr
    height: int
    hwndOwner: System.IntPtr
    lStructSize: int
    ptImageSize: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CustomDialogs.POINTF
    rtMargin: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CustomDialogs.RECT
    scale: float
    width: int

class GetBatchFileInfo(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(
        self,
        info: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CustomDialogs.BATCHFILEINFO,
        result: System.IAsyncResult,
    ) -> bool: ...
    def BeginInvoke(
        self,
        info: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CustomDialogs.BATCHFILEINFO,
        callback: System.AsyncCallback,
        object: Any,
    ) -> System.IAsyncResult: ...
    def Invoke(
        self,
        info: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CustomDialogs.BATCHFILEINFO,
    ) -> bool: ...

class NativeMethods:  # Class
    @staticmethod
    def ShowExportGraphicsFileDialog(
        dlg: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CustomDialogs.EXPORTGRAPHICSFILEDIALOG,
    ) -> bool: ...
    @staticmethod
    def ExportFileDialog(
        dlg: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CustomDialogs.EXPORTFILEDIALOG,
    ) -> bool: ...
    @staticmethod
    def PrintGraphicsDialog(
        dlg: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CustomDialogs.PRINTGRAPHICSDIALOG,
    ) -> int: ...
    @staticmethod
    def ShowOpenBatchDialog(
        dlg: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CustomDialogs.OPENBATCHDIALOG,
    ) -> bool: ...
    @staticmethod
    def GraphicsPageSetupDialog(
        dlg: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CustomDialogs.GRAPHICSPAGESETUPDIALOG,
    ) -> bool: ...
    @staticmethod
    def GetDllDirectory(length: int, builder: System.Text.StringBuilder) -> bool: ...
    @staticmethod
    def ShowOpenDirectoriesDialog(
        dlg: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CustomDialogs.OPENDIRECTORIESDIALOG,
        folders: str,
    ) -> bool: ...
    @staticmethod
    def SetDllDirectory(lpPathName: str) -> bool: ...

class OBDFLAGS(System.IConvertible, System.IComparable, System.IFormattable):  # Struct
    OBD_AUDITTRAIL: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CustomDialogs.OBDFLAGS
    ) = ...  # static # readonly
    OBD_AUDITTRAIL_CHECKBOX: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CustomDialogs.OBDFLAGS
    ) = ...  # static # readonly
    OBD_AUDITTRAIL_CHECKBOX_DISABLED: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CustomDialogs.OBDFLAGS
    ) = ...  # static # readonly
    OBD_FILE_MUST_EXIST: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CustomDialogs.OBDFLAGS
    ) = ...  # static # readonly
    OBD_HIDE_AUDITTRAIL_COLUMN: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CustomDialogs.OBDFLAGS
    ) = ...  # static # readonly
    OBD_NO_OVERWRITE: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CustomDialogs.OBDFLAGS
    ) = ...  # static # readonly
    OBD_READONLY: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CustomDialogs.OBDFLAGS
    ) = ...  # static # readonly
    OBD_READONLY_CHECKBOX: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CustomDialogs.OBDFLAGS
    ) = ...  # static # readonly
    OBD_SAVE: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CustomDialogs.OBDFLAGS
    ) = ...  # static # readonly

class OPENBATCHDIALOG:  # Struct
    Flags: int
    hwndOwner: System.IntPtr
    lStructSize: int
    lpfnGetBatchFileInfo: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CustomDialogs.GetBatchFileInfo
    )
    lpstrBatchFileExtensions: str
    lpstrBatchFolderExtension: str
    lpstrFile: str
    lpstrFilter: str
    lpstrHelpFile: str
    lpstrInitialDir: str
    lpstrOKButtonText: str
    lpstrResultsFolder: str
    lpstrTitle: str
    nFilterIndex: int
    nHelpTopicId: int

class OPENDIRECTORIESDIALOG:  # Struct
    Flags: int
    bstrDirectories: System.IntPtr
    hwndOwner: System.IntPtr
    lStructSize: int
    lpstrExtension: str
    lpstrFileFilter: str
    lpstrHelpFile: str
    lpstrInitialDir: str
    lpstrTitle: str
    nHelpTopicId: int

class OSDFLAGS(System.IConvertible, System.IComparable, System.IFormattable):  # Struct
    OSD_ALLOWMULTISELECT: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CustomDialogs.OSDFLAGS
    ) = ...  # static # readonly
    OSD_DIRECTORYMUSTEXIST: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CustomDialogs.OSDFLAGS
    ) = ...  # static # readonly
    OSD_READONLY: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CustomDialogs.OSDFLAGS
    ) = ...  # static # readonly
    OSD_READONLY_CHECKBOX: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CustomDialogs.OSDFLAGS
    ) = ...  # static # readonly

class PGDFLAGS(System.IConvertible, System.IComparable, System.IFormattable):  # Struct
    PGD_ADJUSTTO: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CustomDialogs.PGDFLAGS
    ) = ...  # static # readonly
    PGD_COLLATE: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CustomDialogs.PGDFLAGS
    ) = ...  # static # readonly
    PGD_CURRENTPAGE: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CustomDialogs.PGDFLAGS
    ) = ...  # static # readonly
    PGD_FITTO: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CustomDialogs.PGDFLAGS
    ) = ...  # static # readonly
    PGD_FITTOSHEET: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CustomDialogs.PGDFLAGS
    ) = ...  # static # readonly
    PGD_FITTOSHEETWIDTH: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CustomDialogs.PGDFLAGS
    ) = ...  # static # readonly
    PGD_PRINTTOFILE: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CustomDialogs.PGDFLAGS
    ) = ...  # static # readonly
    PGD_SOMEPAGES: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CustomDialogs.PGDFLAGS
    ) = ...  # static # readonly
    PGD_UNIT_INCHES: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CustomDialogs.PGDFLAGS
    ) = ...  # static # readonly

class POINTF:  # Struct
    x: float
    y: float

class PRINTGRAPHICSDIALOG:  # Struct
    Flags: int
    PRINTPAGE_SIZE: int = ...  # static # readonly
    hDevMode: System.IntPtr
    hDevNames: System.IntPtr
    height: int
    hwndOwner: System.IntPtr
    lStructSize: int
    lpPageRanges: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CustomDialogs.PRINTPAGERANGE
    ]
    nCopies: int
    nPageRanges: int
    nPages: int
    scale: float
    width: int

class PRINTPAGERANGE:  # Struct
    nPageFrom: int
    nPageTo: int

class PrintGraphicsDialogResult(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Apply: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CustomDialogs.PrintGraphicsDialogResult
    ) = ...  # static # readonly
    Cancel: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CustomDialogs.PrintGraphicsDialogResult
    ) = ...  # static # readonly
    Error: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CustomDialogs.PrintGraphicsDialogResult
    ) = ...  # static # readonly
    Print: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CustomDialogs.PrintGraphicsDialogResult
    ) = ...  # static # readonly

class RECT:  # Struct
    bottom: int
    left: int
    right: int
    top: int

class SetCurrentFolder(System.IDisposable):  # Class
    def __init__(self) -> None: ...
    def Dispose(self) -> None: ...
